# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">About

## Summary

Skill used to provide information about this assistant.

## Description

This skill provides information about Neon. You can ask about licensing and your Neon installation. This skill also
provides formatted examples for installed skills.

## Examples
- Tell me my license.
- Tell me my skills.
- What can you do?

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)
[NeonGeckoCom](https://github.com/NeonGeckoCom)

## Category
**Daily**
Information

## Tags
#NeonGecko Original
#NeonAI
